@@ -1,15 +1,18 @@
-# @(#)$Ident: Schema.pm 2013-12-31 17:05 pjf ;
+# @(#)$Ident: Schema.pm 2014-01-13 13:52 pjf ;
 
 package File::DataClass::Schema;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.30.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.31.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
 use Class::Null;
 use File::DataClass::Cache;
 use File::DataClass::Constants;
-use File::DataClass::Functions qw( ensure_class_loaded merge_attributes throw );
+use File::DataClass::Functions qw( ensure_class_loaded first_char
+                                   qualify_storage_class map_extension2class
+                                   merge_attributes supported_extensions
+                                   throw );
 use File::DataClass::IO;
 use File::DataClass::ResultSource;
 use File::DataClass::Storage;
@@ -60,9 +63,6 @@ has 'storage'                  => is => 'rw',   isa => Object,
 has 'storage_attributes'       => is => 'ro',   isa => HashRef,
    default                     => sub { {} };
 
-has 'storage_base'             => is => 'ro',   isa => ClassName,
-   default                     => 'File::DataClass::Storage';
-
 has 'storage_class'            => is => 'rw',   isa => Str,
    default                     => 'JSON', lazy => TRUE;
 
@@ -120,8 +120,8 @@ sub _build_source_registrations {
 sub _build_storage {
    my $self = shift; my $class = $self->storage_class;
 
-   if ('+' eq substr $class, 0, 1) { $class = substr $class, 1 }
-   else { $class = $self->storage_base."::${class}" }
+   if (first_char $class eq '+') { $class = substr $class, 1 }
+   else { $class = qualify_storage_class $class }
 
    ensure_class_loaded $class;
 
@@ -139,8 +139,14 @@ sub dump {
    return $self->storage->dump( $path, $args->{data} );
 }
 
-sub extensions {
-   return EXTENSIONS;
+sub extensions { # Deprecated
+   my $extns = {};
+
+   warn "DEPRECATED: Calling F::DC::Schema::extensions as a class method\n";
+
+   $extns->{ $_ } = map_extension2class( $_ ) for (supported_extensions());
+
+   return $extns;
 }
 
 sub load {
@@ -160,7 +166,7 @@ sub resultset {
 sub source {
    my ($self, $moniker) = @_;
 
-   $moniker or throw class => Unspecified, args => [ 'Result source' ];
+   $moniker or throw class => Unspecified, args => [ 'result source' ];
 
    my $source = $self->source_registrations->{ $moniker }
       or throw error => 'Result source [_1] unknown', args => [ $moniker ];
@@ -206,7 +212,7 @@ File::DataClass::Schema - Base class for schema definitions
 
 =head1 Version
 
-This document describes version v0.30.$Rev: 1 $
+This document describes version v0.31.$Rev: 1 $
 
 =head1 Synopsis
 
@@ -346,6 +352,8 @@ successful
 
    \%extension_map = $self->extensions;
 
+B<DEPRECATED>: Use the function C<extension2class> instead
+
 Returns a hash ref that maps filename extensions (keys) onto storage
 subclasses (values)
 
